<?xml version="1.0"?>
<xsl:stylesheet
   xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0"
>

<!-- !!! Sablona je celmi podobna s sablonou template_xml_table.xsl - pokud ji budes opravovat, tak pripadnou upravu pokud to pujde zakomponuj i do te druhe -->

<!-- = definice "vestavenych" sablon - v MS IE 5 nejsou vestavene, proto je zde zvlast definuji (pozn.: schvalne nejsou strukturovany) -->

   <xsl:template match="*"><xsl:apply-templates/></xsl:template>

   <xsl:template match="text()"><xsl:value-of select="."/></xsl:template>

<!-- = zaklad stranky = -->

  <xsl:template match="/">
      <html>
      <!-- HTML hlavicka -->
      <head>
         <title>
            <xsl:value-of select="table/query/title"/>
         </title>
         <base>
            <xsl:attribute name="href"><xsl:value-of select="table/query/base/@href"/></xsl:attribute>
         </base>
         <link rel="stylesheet" type="text/css" href="../lib/maccess.css"></link>
         <link rel="stylesheet" type="text/css" href="../lib/template_xml_table.css"></link>
         <link rel="stylesheet" type="text/css" media="print" href="../lib/maccess_print.css"></link>
         <script type="text/javascript" src="../lib/template_table.js"></script>
      </head>
      <!-- HTML telicko -->
      <body>
         <!-- zahlavi dokumentu -->
         <xsl:apply-templates select="table/query/header"/>
         <!-- tabulka -->
         <div id="restore">
            <xsl:apply-templates select="table"/>
         </div>
         <!-- limit -->
         <p>
            <xsl:apply-templates select="table/query/limit"/>
         </p>
         <!-- pata dokumentu -->
         <p>
            <xsl:apply-templates select="table/query/footer"/>
         </p>
      </body>
      </html>
   </xsl:template>  
  
<!-- = tabulka = -->

   <xsl:template match="/table">
      <table cellspacing="0px" border="1">
         <!-- zakladni informace o sloupcich - zarovnani, viditelnost a podobne -->
         <colgroup>
            <xsl:for-each select="cols/col">
               <col>
                  <xsl:attribute name="align"><xsl:choose><xsl:when test="@type='number' or @type='date' or @type='time' or @type='dateTime'">right</xsl:when><xsl:otherwise>left</xsl:otherwise></xsl:choose></xsl:attribute>
                  <xsl:attribute name="class">chosen<xsl:value-of select="@chosen"/></xsl:attribute>
                  <xsl:attribute name="style"><xsl:choose><xsl:when test="@show='1'">display:;</xsl:when><xsl:otherwise>display: none;</xsl:otherwise></xsl:choose></xsl:attribute>
               </col>
            </xsl:for-each>
         </colgroup>
         <!-- hlavicka tabulky -->
         <tr>
            <xsl:apply-templates select="cols/col"/>
         </tr>
         <!-- telo tabulky -->
         <xsl:apply-templates select="rows"/>
      </table>
   </xsl:template>

   <!-- hlavicka tabulky -->
   <xsl:template match="/table/cols/col">
      <th>
         <xsl:apply-templates/>
      </th>
   </xsl:template>



   <!-- telo tabulky -->
   <xsl:template match="/table//rows">
      <xsl:apply-templates/>
      <xsl:variable name="depth_now" select="count(ancestor::node())-2"/>
      <xsl:variable name="id" select="generate-id()"/>
      <!-- suma tabulky -->
      <xsl:if test="/table/cols/col/@summary='sum'">
         <xsl:if test="not(row)">
            <tr>
               <td style="font-size: 0px">
                  <xsl:attribute name="colspan"><xsl:value-of select="$col_count"/></xsl:attribute>
                  <xsl:attribute name="class">heading<xsl:value-of select="$depth_now"/></xsl:attribute>
                  &#160;
               </td>
            </tr>
         </xsl:if>
         <tr>
            <xsl:for-each select="/table/cols/col">
               <td>
                  <xsl:attribute name="class">summary<xsl:value-of select="$depth_now"/></xsl:attribute>
                  <xsl:choose>
                     <xsl:when test="@summary='sum'">
                        <xsl:variable name="position" select="position()"/>
                        <xsl:value-of select="sum(//rows[generate-id()=$id]//row/*[$position][attribute::*='number'])"/>
                     </xsl:when>
                     <xsl:otherwise>
                        &#160;
                     </xsl:otherwise>
                  </xsl:choose>
               </td>
            </xsl:for-each>
         </tr>
      </xsl:if>
   </xsl:template>

   <!-- nadpisy group -->
   <xsl:template match="/table//rows/rows_heading">
      <xsl:variable name="depth_now" select="count(ancestor::node())-3"/>
      <tr>
         <xsl:if test="/table/cols/col/@name='icon'">
            <td>
            </td>
         </xsl:if>
         <td>
            <xsl:choose>
               <xsl:when test="/table/cols/col/@name='icon'">
                  <xsl:attribute name="colspan"><xsl:value-of select="($col_count)-1"/></xsl:attribute>
               </xsl:when>
               <xsl:otherwise>
                  <xsl:attribute name="colspan"><xsl:value-of select="$col_count"/></xsl:attribute>
               </xsl:otherwise>
            </xsl:choose>
            <xsl:attribute name="class">heading<xsl:value-of select="$depth_now"/></xsl:attribute>
            <xsl:if test="@style">
               <xsl:attribute name="style"><xsl:value-of select="@style"/></xsl:attribute>
            </xsl:if>
            <div>
               <xsl:choose>
                  <xsl:when test="not(@href)">
                        <xsl:apply-templates/>
                  </xsl:when>
                  <xsl:otherwise>
                     <a>
                        <xsl:if test="@style">
                           <xsl:attribute name="style"><xsl:value-of select="@style"/></xsl:attribute>
                        </xsl:if>
                        <xsl:attribute name="href"><xsl:value-of select="@href"/></xsl:attribute>
                        <xsl:apply-templates/>
                     </a>
                  </xsl:otherwise>
               </xsl:choose>
            </div>
         </td>
      </tr>
   </xsl:template>



   <!-- radky tabulky -->
   <xsl:template match="/table//rows/row">
      <tr>
         <xsl:attribute name="onclick">change_class(this)</xsl:attribute>
         <xsl:if test="@chosen!='0'"><xsl:attribute name="class">chosen<xsl:value-of select="@chosen"/></xsl:attribute></xsl:if>
         <xsl:for-each select="*">
            <td>
               <xsl:if test="@style">
                  <xsl:attribute name="style"><xsl:value-of select="@style"/></xsl:attribute>
               </xsl:if>
               <xsl:choose>
                  <xsl:when test="not(@href)">
                        <xsl:apply-templates select="."/>
                  </xsl:when>
                  <xsl:otherwise>
                     <a>
                        <xsl:if test="@style">
                           <xsl:attribute name="style"><xsl:value-of select="@style"/></xsl:attribute>
                        </xsl:if>
                        <xsl:attribute name="href"><xsl:value-of select="@href"/></xsl:attribute>
                        <xsl:apply-templates select="."/>
                     </a>
                  </xsl:otherwise>
               </xsl:choose>
            </td>
         </xsl:for-each>
      </tr>
   </xsl:template>

   <!-- jednotlive hodnoty bunky tabulky -->
   <xsl:template match="/table//rows/row/*|/table//rows/rows_heading/*">
      <xsl:apply-templates/>
   </xsl:template>

<!-- = limit -->

   <xsl:template match="/table/query/limit">
      <a>
         <xsl:attribute name="href"><xsl:value-of select="@href"/></xsl:attribute>
         <xsl:value-of select="."/>
      </a>
   </xsl:template>

<!-- = vsechny elementy xhtml zkopiruji na vystup svuj strom -->

   <xsl:template match="xhtml//@*|xhtml//*"><xsl:copy><xsl:apply-templates select="@*|*|text()"/></xsl:copy></xsl:template>

<!-- = hlavni promene -->
   <xsl:variable name="col_count" select="count(/table/cols/col)"/>

</xsl:stylesheet>

